R/azmpmap.R
azmpmap.Rd
This generates a leaflet plot of the geospatial files stored at ftp://ftp.dfo-mpo.gc.ca/AZMP_Maritimes/azmpdata/data/lookup/polygons/.
azmpmap(quiet = T)
default is T This indicates whether or not you want to see messages related to the transformation of data from the ftp site to spatial objects.
T
Mike McMahon, Mike.McMahon@dfo-mpo.gc.ca
if (FALSE) { # \dontrun{ map <- azmpmap() } # }