Search through azmpdata datasets by keywords. Default searches through all dataset variable names, but options (`help_search`) can be used to search through all `azmpdata` help documentation text including variable definitions and metadata.
variable_lookup(keywords, search_help = FALSE, lib.loc = NULL)Search keywords (if using multiple, create a vector of character strings using `c()`)
a logical value determining whether or not help documentation text should also be searched
(optional) passed to find.package to find help documentation through which to search - a character vector describing the location of R library trees to search through, or NULL. The default value of NULL corresponds to checking the loaded namespace, then all libraries currently known in .libPaths().
if (FALSE) { # \dontrun{
res <- variable_lookup('nitrate')
res2 <- variable_lookup("nitrate", search_help = T)
} # }